@@ -3,7 +3,7 @@ package App::JYJ;
 use strict;
 use warnings;
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
 
 use JSON::PP;
 use YAML::PP;
@@ -15,7 +15,7 @@ sub run {
     my $output;
     my $json = JSON::PP->new->pretty->indent_length(2);
     my $yaml = YAML::PP->new;
-    if ($input =~ /\A[\{\[]/) {
+    if ($input =~ /\A\s*[\{\[]/) {
         my $data = $json->decode($input);
         $output = $yaml->dump($data);
     }
